@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -30,7 +30,7 @@
 MBoxImporterKernel::MBoxImporterKernel(QObject *parent)
     : QObject(parent)
 {
-    mIdentityManager = new KIdentityManagement::IdentityManager(true, this);
+    mIdentityManager = KIdentityManagement::IdentityManager::self();
     Akonadi::Session *session = new Akonadi::Session("MBox importer Kernel ETM", this);
     mFolderCollectionMonitor = new MailCommon::FolderCollectionMonitor(session, this);
 
@@ -53,7 +53,7 @@ KIdentityManagement::IdentityManager *MBoxImporterKernel::identityManager()
 
 MessageComposer::MessageSender *MBoxImporterKernel::msgSender()
 {
-    return 0;
+    return nullptr;
 }
 
 Akonadi::EntityMimeTypeFilterModel *MBoxImporterKernel::collectionModel() const
@@ -74,7 +74,7 @@ void MBoxImporterKernel::syncConfig()
 MailCommon::JobScheduler *MBoxImporterKernel::jobScheduler() const
 {
     Q_ASSERT(false);
-    return 0;
+    return nullptr;
 }
 
 Akonadi::ChangeRecorder *MBoxImporterKernel::folderCollectionMonitor() const
