@@ -17,8 +17,8 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef MBOXIMPORTERKERNEL_H
-#define MBOXIMPORTERKERNEL_H
+#ifndef MBOXIMPORTKERNEL_H
+#define MBOXIMPORTKERNEL_H
 
 #include <MailCommon/MailInterfaces>
 
@@ -58,10 +58,10 @@ public:
     void expunge(Akonadi::Collection::Id col, bool sync) override;
 
 private:
-    KIdentityManagement::IdentityManager *mIdentityManager;
-    MailCommon::FolderCollectionMonitor *mFolderCollectionMonitor;
-    Akonadi::EntityTreeModel *mEntityTreeModel;
-    Akonadi::EntityMimeTypeFilterModel *mCollectionModel;
+    KIdentityManagement::IdentityManager *mIdentityManager= nullptr;
+    MailCommon::FolderCollectionMonitor *mFolderCollectionMonitor= nullptr;
+    Akonadi::EntityTreeModel *mEntityTreeModel= nullptr;
+    Akonadi::EntityMimeTypeFilterModel *mCollectionModel= nullptr;
 };
 
 #endif
