@@ -17,8 +17,8 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef IMPORTMAILPAGE_H
-#define IMPORTMAILPAGE_H
+#ifndef MBOXIMPORTWIDGET_H
+#define MBOXIMPORTWIDGET_H
 
 #include <QWidget>
 
@@ -54,7 +54,7 @@ Q_SIGNALS:
     void importMailsClicked();
 
 private:
-    Ui::MBoxImportWidget *ui;
+    Ui::MBoxImportWidget *ui = nullptr;
 };
 
-#endif // IMPORTMAILPAGE_H
+#endif // MBOXIMPORTWIDGET_H
